@@ -70,6 +70,8 @@ jitoptimize_ode <- function (de,prob){
   mtk <- julia_pkg_import("ModelingToolkit",functions)
 
   odesys = mtk$modelingtoolkitize(prob)
+  odesys = mtk$complete(odesys)
+  
   JuliaCall::julia_assign("odesys", odesys)
   jul_f = JuliaCall::julia_eval("jitf = ODEFunction(odesys,jac=true)")
   JuliaCall::julia_assign("u0", prob$u0)
@@ -104,6 +106,7 @@ jitoptimize_sde <- function (de,prob){
   mtk <- julia_pkg_import("ModelingToolkit",functions)
 
   sdesys = mtk$modelingtoolkitize(prob)
+  sdesys = mtk$complete(sdesys)
   JuliaCall::julia_assign("sdesys", sdesys)
   jul_f = JuliaCall::julia_eval("jitf = SDEFunction(sdesys,jac=true)")
   JuliaCall::julia_assign("u0", prob$u0)
